Overview
===============================================================================

The LINCC Frameworks team has built the import tool hoping to handle catalogs
in various formats. We've learned some lessons in importing public data sets, 
and provide steps to import those catalogs in case they help anyone else.

Catalogs
-------------------------------------------------------------------------------

* :doc:`allwise`
* :doc:`neowise`
* :doc:`tic`
